const { paginator } = require('#client');
const { PERMISSION_GROUPS } = require('#constants');

const { createEmbed, page } = require("#utils/embed");
const { icon } = require('#utils/markdown');
const { editOrReply } = require("#utils/message");
const { getUser } = require("#utils/users");

module.exports = {
  name: 'banner',
  label: 'user',
  aliases: ['b'],
  metadata: {
    description: 'Displays someones profile banner. Accepts IDs, Mentions, or Usernames.',
    description_short: 'Get discord user avatars',
    examples: ['avatar labsCore'],
    category: 'info',
    usage: 'avatar [<user>]',
    slashCommmand: 'banner'
  },
  permissionsClient: [...PERMISSION_GROUPS.baseline],
  run: async (context, args) => {
    context.triggerTyping();
    if(!args.user) args.user = context.userId;
    let u = await getUser(context, args.user)
    if(!u || !u.user) return editOrReply(context, createEmbed("warning", context, "No users found."))

    if(!u.user.banner && !u.member?.banner) return editOrReply(context, createEmbed("warning", context, "User has no banners."))
    
    let pages = []
    
    if(!u.member?.banner && u.member) u.member = await context.guild.fetchMember(u.user.id)

    if(u.member?.banner) {
      pages.push(page(createEmbed("default", context, {
        image: {
          url: `https://cdn.discordapp.com/guilds/${context.guild.id}/users/${u.member.id}/banners/${u.member.banner}.png` + "?size=4096"
        }
      })))

      pages.push(page(createEmbed("default", context, {
        image: {
          url: u.user.bannerUrl + '?size=4096'
        }
      })))

      await paginator.createPaginator({
        context,
        pages,
        buttons: [{
          customId: "next",
          emoji: icon("button_user_profile_swap"),
          label: "Toggle Server/Global Banner",
          style: 2
        }]
      });
    } else {
      return editOrReply(context, createEmbed("default", context, {
        image: {
          url: u.user.bannerUrl + '?size=4096'
        }
      }))
    }
  },
};